define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} de ${1} ${0}",
	"firstTip": "Primera pàgina",
	"lastTip": "Darrera pàgina",
	"nextTip": "Pàgina següent",
	"prevTip": "Pàgina anterior",
	"itemTitle": "elements",
	"singularItemTitle": "element",
	"pageStepLabelTemplate": "Pàgina ${0}",
	"pageSizeLabelTemplate": "${0} elements per pàgina",
	"allItemsLabelTemplate": "Tots els elements",
	"gotoButtonTitle": "Vés a una pàgina específica",
	"dialogTitle": "Vés a pàgina",
	"dialogIndication": "Especifiqueu el número de pàgina",
	"pageCountIndication": " (${0} pàgines)",
	"dialogConfirm": "Vés-hi",
	"dialogCancel": "Cancel·la",
	"all": "tot"
})
//end v1.x content
);
